Graph.EdgeSpecificationError exception (multigraph v0.16.1-mg.2)

This exception is raised when a Graph function expects one or more valid edge specifications, but receives a term which does not match one of the allowed specification patterns.